@@ -156,7 +156,7 @@ public final class MailNotifyActivator extends HousekeepingActivator {
 
             // Start UPD listener
             startUdpListener(registry, config);
-        } catch (final Exception e) {
+        } catch (Exception e) {
             LOG.error("", e);
             throw e;
         }
@@ -180,7 +180,7 @@ public final class MailNotifyActivator extends HousekeepingActivator {
             }
 
             Services.set(null);
-        } catch (final Exception e) {
+        } catch (Exception e) {
             LOG.error("", e);
             throw e;
         }
@@ -229,7 +229,7 @@ public final class MailNotifyActivator extends HousekeepingActivator {
             try {
                 config.udpListenPort = Integer.parseInt(tmp.trim());
                 sb.append("\t").append(PROP_UDP_LISTEN_PORT).append(": ").append(config.udpListenPort).append(ls);
-            } catch (final NumberFormatException e) {
+            } catch (NumberFormatException e) {
                 throw ConfigurationExceptionCodes.PROPERTY_NOT_AN_INTEGER.create(PROP_UDP_LISTEN_PORT);
             }
         } else {
